import AlarmLevelBox from '@/components/DictionaryBox/alarmLevel';
import TableActionCard from '@/components/TableActionCard';
import IsDelete from '@/components/TableActionCard/isDelete';
import { alarmLevelStatusEnum } from '@/enums/status';
import {
  deleteDeviceCategoryDeleteDeviceCategory,
  postDeviceCategoryGetDeviceCategoryList,
} from '@/services/device/DeviceCategory';
import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { PageContainer, ProTable } from '@ant-design/pro-components';
import { FormattedMessage, useIntl } from '@umijs/max';
import { Space, message } from 'antd';
import React, { useRef, useState } from 'react';
import { proTablePaginationOptions } from '../../../../config/defaultTable';
const DeviceCategoryList: React.FC = () => {
  /**
   * @en-US International configuration
   * @zh-CN 国际化配置
   * */
  const intl = useIntl();
  const actionRef = useRef<ActionType>();
  //  动态设置每页数量
  const [currentPageSize, setCurrentPageSize] = useState<number>(10);

  const handleDestroy = async (selectedRow: API.DeviceCategory) => {
    deleteDeviceCategoryDeleteDeviceCategory({ id: selectedRow.id })
      .then(() => {
        message.success(intl.formatMessage({ id: 'common.success', defaultMessage: '$$$' }));
        actionRef.current?.reload();
      })
      .catch(() => {
        message.error(intl.formatMessage({ id: 'common.failure', defaultMessage: '$$$' }));
      });
  };

  const columns: ProColumns<API.DeviceCategory>[] = [
    {
      title: <FormattedMessage id="alarm.setting.table.list.name" defaultMessage="$$$" />,
      dataIndex: 'name',
      hideInSearch: true,
    },

    {
      title: <FormattedMessage id="alarm.setting.table.list.code" defaultMessage="$$$" />,
      dataIndex: 'code',
      hideInSearch: true,
    },
    {
      title: <FormattedMessage id="alarm.setting.table.list.level" defaultMessage="$$$" />,
      dataIndex: 'level',
      hideInSearch: true,
      render: (text, record, index) => {
        console.log(text, record, index, 'level_record');
        const currVal = index % 6;
        const currLevel = alarmLevelStatusEnum[currVal];
        return (
          <Space>
            <AlarmLevelBox {...currLevel}></AlarmLevelBox>
            <span style={{ color: currLevel.color }}>{currLevel.label}</span>
          </Space>
        );
      },
    },
    {
      title: <FormattedMessage id="alarm.list.table.list.deviceGroup" defaultMessage="$$$" />,
      dataIndex: 'deviceGroup',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },
    {
      title: <FormattedMessage id="alarm.list.table.list.alarmTime" defaultMessage="$$$" />,
      dataIndex: 'createTime',
      sorter: true,
      hideInSearch: true,
      valueType: 'dateTime',
    },

    {
      title: <FormattedMessage id="pages.searchTable.titleOption" defaultMessage="Operating" />,
      dataIndex: 'option',
      valueType: 'option',
      fixed: 'right',
      render: (_, record) => [
        <TableActionCard
          key="TableActionCardRef"
          renderActions={[
            {
              key: 'destroy',
              renderDom: (
                <IsDelete
                  buttonType="deleteIcon"
                  deleteApi={() => {
                    handleDestroy(record).then(() => {});
                  }}
                ></IsDelete>
              ),
            },
          ]}
        ></TableActionCard>,
      ],
    },
  ];
  return (
    <PageContainer>
      <ProTable<API.DeviceCategory>
        cardProps={{
          bodyStyle: {
            padding: 20
          }
        }}
        options={{ fullScreen: false, setting: false, density: false, reload: false }}
        actionRef={actionRef}
        rowKey="key"
        search={false}
        pagination={{
          ...proTablePaginationOptions,
          pageSize: currentPageSize,
          onChange: (page, pageSize) => setCurrentPageSize(pageSize),
        }}
        columnsState={{
          persistenceKey: 'device_category_list',
          persistenceType: 'localStorage',
        }}
        request={async (params = {}, sort) => {
          const { current, ...rest } = params;
          const reqParams = {
            page: current,
            desc: false,
            orderKey: '',
            ...rest,
          };
          if (sort && Object.keys(sort).length) {
            reqParams.orderKey = Object.keys(sort)[0];
            let sort_select = sort[reqParams.orderKey];
            reqParams.desc = sort_select === 'descend';
          }
          let resp = await postDeviceCategoryGetDeviceCategoryList({ ...reqParams });
          return {
            data: resp.data.list.map((v: API.DeviceCategory) => {
              return { ...v, key: v.id };
            }),
            success: resp.success,
            total: resp.data.total,
            current: resp.data.page,
            pageSize: resp.data.pageSize,
          };
        }}
        columns={columns}
      />
    </PageContainer>
  );
};

export default DeviceCategoryList;
